# Table of Contents

- [retrieving-event-logs-for-fact-sheet](<./retrieving-event-logs-for-fact-sheet.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Retrieving Event Logs for a Fact Sheet (GraphQL)](<./Retrieving-Event-Logs-for-a-Fact-Sheet-GraphQL.md>)
  - [Was this page helpful?](<./Retrieving-Event-Logs-for-a-Fact-Sheet-GraphQL/Was-this-page-helpful.md>)
